# @dynatrace-sdk/client-filter-segment-management

[![npm](https://img.shields.io/badge/npm-v1.6.3-blue)](https://www.npmjs.com/package/@dynatrace-sdk/client-filter-segment-management/v/1.6.3)
[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

Filter-Segment Management for Grail.

Slice, dice and contextualize your data to make it easier to find, understand and work with.



## Installation

```bash
npm install @dynatrace-sdk/client-filter-segment-management
```


## Getting help

- Visit [SDK for Typescript](https://developer.dynatrace.com/reference/sdks/) guide in the [Dynatrace Developer](https://developer.dynatrace.com/)
- Ask a question in the [Dynatrace Community](https://community.dynatrace.com/)


## License

This SDK is distributed under the [Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0), see LICENSE for more information.


# API reference

Full API reference for the latest version of the SDK is also available at the [Dynatrace Developer](https://developer.dynatrace.com/reference/sdks/client-filter-segment-management/).

## filterSegmentsClient

```js
import { filterSegmentsClient } from '@dynatrace-sdk/client-filter-segment-management';
```


<a name="createfiltersegment"></a>
### createFilterSegment

<div class="padding-bottom--md">
<strong>filterSegmentsClient.createFilterSegment(config): Promise&lt;<a href="#detailedfiltersegment">DetailedFilterSegment</a>&gt;</strong>

<div class="padding-left--md">

Create a new filter-segment.

Create a new segment and define data.

Required scopes:

- `storage:filter-segments:write`
- `storage:filter-segments:share` if `isPublic` is set to `true`

### New Filter-Segment

Provide a name and an optional description for the filter-segment.

#### Variables

Create variables to apply in your filter-segment data filters

#### Includes (Segment data)

Include all data that should be accessible when applying the filter-segment

#### IsPublic (Visibility)

- `false`: The filter-segment is private and only visible to the owner
- `true`: The filter-segment is visible to everyone in the environment



</div>


#### Parameters

| Name | Type |
| --- | --- |
|config.body<sup>*required</sup>|<a href="#newfiltersegment" target="_blank" rel="noopener noreferrer">NewFilterSegment</a>| 




#### Returns

| Return type | Status code | Description |
|---|---|---|
|[DetailedFilterSegment](#detailedfiltersegment)|201|Filter-segment successfully created.|


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError|Filter-segment Bad Request. \| unauthorized \| missing permissions|


<details>
<summary>
Code example
</summary>

```ts
import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";

const data = await filterSegmentsClient.createFilterSegment(
  {
    body: {
      name: "dev_environment",
      description:
        "only includes data of the dev environment",
      variables: {
        type: "query",
        value: "fetch logs | limit 1",
      },
      isPublic: false,
      includes: [
        {
          filter:
            '{"type":"Group","range":{"from":0,"to":19},"logicalOperator":"AND","explicit":false,"children":[{"type":"Statement","range":{"from":0,"to":19},"key":{"type":"Key","textValue":"content","value":"content","range":{"from":0,"to":7}},"operator":{"type":"ComparisonOperator","textValue":"=","value":"=","range":{"from":8,"to":9}},"value":{"type":"String","textValue":"\\"[debug]\\"","value":"[debug]","range":{"from":10,"to":19},"isEscaped":true}}]}',
          dataObject: "logs",
        },
        {
          filter:
            '{"type":"Group","range":{"from":0,"to":18},"logicalOperator":"AND","explicit":false,"children":[{"type":"Statement","range":{"from":0,"to":18},"key":{"type":"Key","textValue":"content","value":"content","range":{"from":0,"to":7}},"operator":{"type":"ComparisonOperator","textValue":"=","value":"=","range":{"from":8,"to":9}},"value":{"type":"String","textValue":"\\"[info]\\"","value":"[info]","range":{"from":10,"to":18},"isEscaped":true}}]}',
          dataObject: "events",
        },
      ],
    },
  },
);
```

</details>



</div>


<a name="deletefiltersegment"></a>
### deleteFilterSegment

<div class="padding-bottom--md">
<strong>filterSegmentsClient.deleteFilterSegment(config): Promise&lt;void&gt;</strong>

<div class="padding-left--md">

Delete a filter-segment.

Remove the filter-segment from the environment for all users.

Required scopes:
- `storage:filter-segments:delete`



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|config.filterSegmentUid<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|UID of the filter-segment |




#### Returns

| Return type | Status code | Description |
|---|---|---|
|void|204|Filter-segment successfully deleted.|


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError|bad request \| unauthorized \| missing permissions \| Not found: the server cannot find the requested filter-segment.|


<details>
<summary>
Code example
</summary>

```ts
import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";

const data = await filterSegmentsClient.deleteFilterSegment(
  { filterSegmentUid: "D82a1jdA23a" },
);
```

</details>



</div>


<a name="getfiltersegment"></a>
### getFilterSegment

<div class="padding-bottom--md">
<strong>filterSegmentsClient.getFilterSegment(config): Promise&lt;<a href="#detailedfiltersegment">DetailedFilterSegment</a>&gt;</strong>

<div class="padding-left--md">

Get filter-segment by UID.

Get filter-segment by its UID.

Required scopes:

- `storage:filter-segments:read`



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|config.addFields|Array&lt;"INCLUDES" &#124; "VARIABLES" &#124; "EXTERNALID" &#124; "RESOURCECONTEXT"&gt;|Add additional fields. |
|config.filterSegmentUid<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|UID of the filter-segment |




#### Returns

| Return type | Status code | Description |
|---|---|---|
|[DetailedFilterSegment](#detailedfiltersegment)|200|Filter-segment successfully retrieved.|


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError|bad request \| unauthorized \| missing permissions \| Not found: the server cannot find the requested filter-segment.|


<details>
<summary>
Code example
</summary>

```ts
import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";

const data = await filterSegmentsClient.getFilterSegment({
  filterSegmentUid: "D82a1jdA23a",
});
```

</details>



</div>


<a name="getfiltersegments"></a>
### getFilterSegments

<div class="padding-bottom--md">
<strong>filterSegmentsClient.getFilterSegments(config): Promise&lt;<a href="#filtersegments" target="_blank" rel="noopener noreferrer">FilterSegments</a>&gt;</strong>

<div class="padding-left--md">

Get all filter-segments.

Returns all filter-segments.
If details like description are not needed then consider using the `:lean` endpoint.

Required scopes:

- `storage:filter-segments:read`



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|config.addFields|Array&lt;"VARIABLES" &#124; "EXTERNALID" &#124; "RESOURCECONTEXT"&gt;|Add additional fields. |




#### Returns

| Return type | Status code | Description |
|---|---|---|
|[FilterSegments](#filtersegments)|200|Filter-segments successfully retrieved.|


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError|bad request \| unauthorized \| missing permissions|


<details>
<summary>
Code example
</summary>

```ts
import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";

const data = await filterSegmentsClient.getFilterSegments();
```

</details>



</div>


<a name="getfiltersegmentsentitymodel"></a>
### getFilterSegmentsEntityModel

<div class="padding-bottom--md">
<strong>filterSegmentsClient.getFilterSegmentsEntityModel(config): Promise&lt;<a href="#filtersegmentnamespacedto">FilterSegmentNamespaceDto</a>&gt;</strong>

<div class="padding-left--md">

Get filter-segment-entity-model.

Returns the filter-segment-entity-model.

Required scopes:

- `storage:filter-segments:read`



</div>



#### Returns

| Return type | Status code | Description |
|---|---|---|
|[FilterSegmentNamespaceDto](#filtersegmentnamespacedto)|200|Filter-segments-entity-model successfully retrieved.|


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError|bad request \| unauthorized \| missing permissions|


<details>
<summary>
Code example
</summary>

```ts
import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";

const data =
  await filterSegmentsClient.getFilterSegmentsEntityModel();
```

</details>



</div>


<a name="getleanfiltersegments"></a>
### getLeanFilterSegments

<div class="padding-bottom--md">
<strong>filterSegmentsClient.getLeanFilterSegments(config): Promise&lt;<a href="#leanfiltersegments" target="_blank" rel="noopener noreferrer">LeanFilterSegments</a>&gt;</strong>

<div class="padding-left--md">

Get all filter-segments in a minimal/lean form.

Returns all filter-segments in a minimal representational form. This endpoint saves resources
and as a result quicker response times can be expected over the more detailed get-all
endpoint.

Required scopes:

- `storage:filter-segments:read`



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|config.addFields|Array&lt;"VARIABLES" &#124; "EXTERNALID" &#124; "RESOURCECONTEXT" &#124; "OWNER"&gt;|Add additional fields. |




#### Returns

| Return type | Status code | Description |
|---|---|---|
|[LeanFilterSegments](#leanfiltersegments)|200|Filter-segments successfully retrieved.|


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError|bad request \| unauthorized \| missing permissions|


<details>
<summary>
Code example
</summary>

```ts
import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";

const data =
  await filterSegmentsClient.getLeanFilterSegments();
```

</details>



</div>


<a name="partiallyupdatefiltersegment"></a>
### partiallyUpdateFilterSegment

<div class="padding-bottom--md">
<strong>filterSegmentsClient.partiallyUpdateFilterSegment(config): Promise&lt;void&gt;</strong>

<div class="padding-left--md">

Partially update a filter-segment.

Update one or more fields of a filter-segment.

Required scopes:
- `storage:filter-segments:write`
- `storage:filter-segments:share` to change `isPublic` to `true`

Following fields can be updated:

- `name`
- `description`
- `isPublic`
- `variables`*
- `includes`*

\* If given the value will be overridden.

Fields not given will be ignored.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|config.body<sup>*required</sup>|<a href="#partialupdatefiltersegment">PartialUpdateFilterSegment</a>| |
|config.filterSegmentUid<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|UID of the filter-segment |
|config.optimisticLockingVersion<sup>*required</sup>|[number](https://developer.mozilla.org/en-US/docs/Glossary/Number)|version which should be updated. used for optimistic locking. |




#### Returns

| Return type | Status code | Description |
|---|---|---|
|void|200|Filter-segment successfully updated.|


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError|bad request \| unauthorized \| missing permissions \| Not found: the server cannot find the requested filter-segment.|


<details>
<summary>
Code example
</summary>

```ts
import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";

const data =
  await filterSegmentsClient.partiallyUpdateFilterSegment({
    filterSegmentUid: "D82a1jdA23a",
    optimisticLockingVersion: 1,
    body: {
      description:
        "only includes data of the development environment",
    },
  });
```

</details>



</div>


<a name="updatefiltersegment"></a>
### updateFilterSegment

<div class="padding-bottom--md">
<strong>filterSegmentsClient.updateFilterSegment(config): Promise&lt;void&gt;</strong>

<div class="padding-left--md">

Update a filter-segment. All fields will be overwritten (also undefined or null fields).

Update one or more fields of a filter-segment.

Required scopes:
- `storage:filter-segments:write`
- `storage:filter-segments:share` to change `isPublic` to `true`

Following fields can be updated:

- `name`
- `description`
- `isPublic`
- `variables`*
- `includes`*

\* Values of the fields will be overridden or removed if not given.

Provide all other fields with unchanged values.



</div>


#### Parameters

| Name | Type | Description |
| --- | --- | --- |
|config.body<sup>*required</sup>|<a href="#updatefiltersegment" target="_blank" rel="noopener noreferrer">UpdateFilterSegment</a>| |
|config.filterSegmentUid<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|UID of the filter-segment |
|config.optimisticLockingVersion<sup>*required</sup>|[number](https://developer.mozilla.org/en-US/docs/Glossary/Number)|version which should be updated. used for optimistic locking. |




#### Returns

| Return type | Status code | Description |
|---|---|---|
|void|200|Filter-segment successfully updated.|


#### Throws

| Error Type | Error Message |
|---|---|
|ErrorEnvelopeError|bad request \| unauthorized \| missing permissions \| Not found: the server cannot find the requested filter-segment.|


<details>
<summary>
Code example
</summary>

```ts
import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";

const data = await filterSegmentsClient.updateFilterSegment(
  {
    filterSegmentUid: "D82a1jdA23a",
    optimisticLockingVersion: 1,
    body: {
      uid: "D82a1jdA23a",
      name: "dev_environment",
      description:
        "only includes data of the development environment",
      variables: {
        type: "query",
        value: "fetch logs | limit 1",
      },
      isPublic: false,
      owner: "john.doe",
      includes: [
        {
          filter:
            '{"type":"Group","range":{"from":0,"to":19},"logicalOperator":"AND","explicit":false,"children":[{"type":"Statement","range":{"from":0,"to":19},"key":{"type":"Key","textValue":"content","value":"content","range":{"from":0,"to":7}},"operator":{"type":"ComparisonOperator","textValue":"=","value":"=","range":{"from":8,"to":9}},"value":{"type":"String","textValue":"\\"[debug]\\"","value":"[debug]","range":{"from":10,"to":19},"isEscaped":true}}]}',
          dataObject: "logs",
        },
        {
          filter:
            '{"type":"Group","range":{"from":0,"to":18},"logicalOperator":"AND","explicit":false,"children":[{"type":"Statement","range":{"from":0,"to":18},"key":{"type":"Key","textValue":"content","value":"content","range":{"from":0,"to":7}},"operator":{"type":"ComparisonOperator","textValue":"=","value":"=","range":{"from":8,"to":9}},"value":{"type":"String","textValue":"\\"[info]\\"","value":"[info]","range":{"from":10,"to":18},"isEscaped":true}}]}',
          dataObject: "events",
        },
      ],
    },
  },
);
```

</details>



</div>

## Types

### CustomValidationErrorInfo

| Name | Type |
| --- | --- |
|message|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|

### DetailedFilterSegment

| Name | Type | Description |
| --- | --- | --- |
|allowedOperations|Array&lt;"READ" &#124; "WRITE" &#124; "DELETE" &#124; "SHARE"&gt;|Defines the allowed operations of the current user. |
|description|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Description of the filter-segment. |
|externalId|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Optional unique identifier of the filter-segment. Used for Dynatrace Configuration as Code |
|includes|Array&lt;<a href="#include">Include</a>&gt;|List of includes of the filter-segment. |
|isPublic|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)|Indicates if the filter-segment is publicly accessible within the tenant. |
|name<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Name of the filter-segment. |
|owner<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Defines the owner of the filter-segment. |
|uid<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Unique identifier of the filter-segment. |
|variables|<a href="#filtersegmentvariables" target="_blank" rel="noopener noreferrer">FilterSegmentVariables</a>|Variables of the filter-segment. |
|version|[number](https://developer.mozilla.org/en-US/docs/Glossary/Number)|Used for optimistic locking. Update requests define with this on which version the data updated is based on. This must match with the version stored, otherwise the update will fail due to concurrent modification. |

### ErrorEnvelope

| Name | Type |
| --- | --- |
|error|<a href="#exceptionalreturn">ExceptionalReturn</a>|

### ErrorInfo

| Name | Type |
| --- | --- |
|message|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|

### ExceptionalReturn

| Name | Type |
| --- | --- |
|code|[number](https://developer.mozilla.org/en-US/docs/Glossary/Number)| 
|errorDetails|Array&lt;<a href="#customvalidationerrorinfo" target="_blank" rel="noopener noreferrer">CustomValidationErrorInfo</a> &#124; <a href="#invalidauditeventserrorinfo">InvalidAuditEventsErrorInfo</a> &#124; <a href="#mediatypeerrorinfo" target="_blank" rel="noopener noreferrer">MediaTypeErrorInfo</a> &#124; <a href="#parametererrorinfo">ParameterErrorInfo</a> &#124; <a href="#proxyerrorinfo" target="_blank" rel="noopener noreferrer">ProxyErrorInfo</a> &#124; <a href="#queryfrontendrawerrorinfo">QueryFrontendRawErrorInfo</a> &#124; <a href="#requestbodyerrorinfo" target="_blank" rel="noopener noreferrer">RequestBodyErrorInfo</a>&gt;| 
|message|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|

### FilterSegment

List of filter-segments.

| Name | Type | Description |
| --- | --- | --- |
|allowedOperations|Array&lt;"READ" &#124; "WRITE" &#124; "DELETE" &#124; "SHARE"&gt;|Defines the allowed operations of the current user. |
|description|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Description of the filter-segment. |
|externalId|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Optional unique identifier of the filter-segment. Used for Dynatrace Configuration as Code |
|isPublic|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)|Indicates if the filter-segment is publicly accessible within the tenant. |
|name<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Name of the filter-segment. |
|owner<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Defines the owner of the filter-segment. |
|uid<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Unique identifier of the filter-segment. |
|variables|<a href="#filtersegmentvariables">FilterSegmentVariables</a>|Variables of the filter-segment. |
|version|[number](https://developer.mozilla.org/en-US/docs/Glossary/Number)|Used for optimistic locking. Update requests define with this on which version the data updated is based on. This must match with the version stored, otherwise the update will fail due to concurrent modification. |

### FilterSegmentNamespaceDto

| Name | Type | Description |
| --- | --- | --- |
|allowedFilterOperations|Array&lt;<a href="#filtersegmentpushdownfilterabledto" target="_blank" rel="noopener noreferrer">FilterSegmentPushDownFilterableDto</a>&gt;|Allowed filter operations. |
|name<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Name of the namespace. |
|types|Array&lt;<a href="#filtersegmenttypedto">FilterSegmentTypeDto</a>&gt;|Types of the namespace. |

### FilterSegmentPropertyDto

| Name | Type |
| --- | --- |
|name|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| 
|type|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|

### FilterSegmentPushDownFilterableDto

Allowed filter operations.

| Name | Type |
| --- | --- |
|filterName|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| 
|supportedAttributes|Array&lt;[string](https://developer.mozilla.org/en-US/docs/Glossary/String)&gt;|

### FilterSegmentRelationshipDto

| Name | Type |
| --- | --- |
|name|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| 
|target|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|

### FilterSegmentTypeDto

Types of the namespace.

| Name | Type |
| --- | --- |
|displayName|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| 
|filtersEntitiesOnly|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)| 
|fromTypes|Array&lt;<a href="#filtersegmentrelationshipdto" target="_blank" rel="noopener noreferrer">FilterSegmentRelationshipDto</a>&gt;| 
|name|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| 
|properties|Array&lt;<a href="#filtersegmentpropertydto">FilterSegmentPropertyDto</a>&gt;| 
|relatedTargetEntityOnly|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)| 
|restrictedParentProperties|Array&lt;[string](https://developer.mozilla.org/en-US/docs/Glossary/String)&gt;|

### FilterSegmentVariables

Variables of the filter-segment.

| Name | Type | Description |
| --- | --- | --- |
|type<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Type of the variable. |
|value<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Value of the variable. |

### FilterSegments

| Name | Type | Description |
| --- | --- | --- |
|filterSegments<sup>*required</sup>|Array&lt;<a href="#filtersegment" target="_blank" rel="noopener noreferrer">FilterSegment</a>&gt;|List of filter-segments. |

### Include

List of includes of the filter-segment.

| Name | Type | Description |
| --- | --- | --- |
|applyTo|Array&lt;[string](https://developer.mozilla.org/en-US/docs/Glossary/String)&gt;|[Experimental] The tables that the entity-filter will be applied to. |
|dataObject<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|The data object that the filter will be applied to. Use '_all_data_object' to apply it to all dataObjects. |
|filter<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Data will be filtered by this value. Field names must only contain letters, numbers and underscores, otherwise they need to be escaped using quotes(`). |
|relationship|<a href="#relationship">Relationship</a>|[Experimental] The relationship of an include which has to be be specified when the data object is an entity view. |

### InvalidAuditEventsErrorInfo

| Name | Type |
| --- | --- |
|invalidAuditEventIndices|Array&lt;[number](https://developer.mozilla.org/en-US/docs/Glossary/Number)&gt;| 
|invalidEventIndices|Array&lt;[number](https://developer.mozilla.org/en-US/docs/Glossary/Number)&gt;| 
|message|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|

### LeanFilterSegment

List of filter-segments.

| Name | Type | Description |
| --- | --- | --- |
|allowedOperations|Array&lt;"READ" &#124; "WRITE" &#124; "DELETE" &#124; "SHARE"&gt;|Defines the allowed operations of the current user. |
|externalId|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Optional unique identifier of the filter-segment. Used for Dynatrace Configuration as Code |
|isPublic|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)|Indicates if the filter-segment is publicly accessible within the tenant. |
|name<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Name of the filter-segment. |
|owner|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Defines the owner of the filter-segment. |
|uid<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Unique identifier of the filter-segment. |
|variables|<a href="#filtersegmentvariables" target="_blank" rel="noopener noreferrer">FilterSegmentVariables</a>|Variables of the filter-segment. |

### LeanFilterSegments

| Name | Type | Description |
| --- | --- | --- |
|filterSegments<sup>*required</sup>|Array&lt;<a href="#leanfiltersegment">LeanFilterSegment</a>&gt;|List of filter-segments. |

### MediaTypeErrorInfo

| Name | Type |
| --- | --- |
|message|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| 
|supportedMediaTypes|Array&lt;[string](https://developer.mozilla.org/en-US/docs/Glossary/String)&gt;|

### NewFilterSegment

| Name | Type | Description |
| --- | --- | --- |
|description|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Description of the filter-segment. |
|externalId|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Optional unique identifier of the filter-segment. Used for Dynatrace Configuration as Code |
|includes|Array&lt;<a href="#newinclude" target="_blank" rel="noopener noreferrer">NewInclude</a>&gt;|List of includes of the filter-segment. |
|isPublic<sup>*required</sup>|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)|Indicates if the filter-segment is publicly accessible within the tenant. |
|name<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Name of the filter-segment. |
|variables|<a href="#filtersegmentvariables">FilterSegmentVariables</a>|Variables of the filter-segment. |

### NewInclude

List of includes of the filter-segment.

| Name | Type | Description |
| --- | --- | --- |
|applyTo|Array&lt;[string](https://developer.mozilla.org/en-US/docs/Glossary/String)&gt;|[Experimental] The tables that the entity-filter will be applied to. |
|dataObject<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|The data object that the filter will be applied to. Use '_all_data_object' to apply it to all dataObjects. |
|filter<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Data will be filtered by this value. Field names must only contain letters, numbers and underscores, otherwise they need to be escaped using quotes(`). |
|relationship|<a href="#newrelationship" target="_blank" rel="noopener noreferrer">NewRelationship</a>|[Experimental] The relationship of an include which has to be be specified when the data object is an entity view. |

### NewRelationship

[Experimental] The relationship of an include which has to be be specified when the data object is an entity view.

| Name | Type | Description |
| --- | --- | --- |
|name<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Name of the relationship. |
|target<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Target of the relationship. |

### ParameterErrorInfo

| Name | Type |
| --- | --- |
|message|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| 
|parameterDescriptor|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|

### PartialUpdateFilterSegment

| Name | Type | Description |
| --- | --- | --- |
|description|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Description of the filter-segment. |
|externalId|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Optional unique identifier of the filter-segment. Used for Dynatrace Configuration as Code |
|includes|Array&lt;<a href="#newinclude">NewInclude</a>&gt;|List of includes of the filter-segment. |
|isPublic|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)|Indicates if the filter-segment is publicly accessible within the tenant. |
|name|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Name of the filter-segment. |
|variables|<a href="#filtersegmentvariables" target="_blank" rel="noopener noreferrer">FilterSegmentVariables</a>|Variables of the filter-segment. |

### ProxyErrorInfo

| Name | Type |
| --- | --- |
|message|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|

### QueryFrontendRawErrorInfo

| Name | Type |
| --- | --- |
|message|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| 
|rawQueryFrontendResponse|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|

### Relationship

[Experimental] The relationship of an include which has to be be specified when the data object is an entity view.

| Name | Type | Description |
| --- | --- | --- |
|name<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Name of the relationship. |
|target<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Target of the relationship. |

### RequestBodyErrorInfo

| Name | Type |
| --- | --- |
|bodyDescriptor|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)| 
|message|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|

### UpdateFilterSegment

| Name | Type | Description |
| --- | --- | --- |
|description|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Description of the filter-segment. |
|externalId|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Optional unique identifier of the filter-segment. Used for Dynatrace Configuration as Code |
|includes|Array&lt;<a href="#newinclude">NewInclude</a>&gt;|List of includes of the filter-segment. |
|isPublic<sup>*required</sup>|[boolean](https://developer.mozilla.org/en-US/docs/Glossary/Boolean)|Indicates if the filter-segment is publicly accessible within the tenant. |
|name<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Name of the filter-segment. |
|owner<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Defines the owner of the filter-segment. |
|uid<sup>*required</sup>|[string](https://developer.mozilla.org/en-US/docs/Glossary/String)|Unique identifier of the filter-segment. |
|variables|<a href="#filtersegmentvariables" target="_blank" rel="noopener noreferrer">FilterSegmentVariables</a>|Variables of the filter-segment. |

## Enums

<a name="detailedfiltersegmentallowedoperationsitem"></a>
### DetailedFilterSegmentAllowedOperationsItem

<div class="padding-left--md">

Defines the allowed operations of the current user.

#### Enum keys

<div class="padding-left--md">

`Delete` | `Read` | `Share` | `Write`

</div>


</div>

<a name="filtersegmentallowedoperationsitem"></a>
### FilterSegmentAllowedOperationsItem

<div class="padding-left--md">

Defines the allowed operations of the current user.

#### Enum keys

<div class="padding-left--md">

`Delete` | `Read` | `Share` | `Write`

</div>


</div>

<a name="getfiltersegmentqueryaddfieldsitem"></a>
### GetFilterSegmentQueryAddFieldsItem

<div class="padding-left--md">



#### Enum keys

<div class="padding-left--md">

`Externalid` | `Includes` | `Resourcecontext` | `Variables`

</div>


</div>

<a name="getfiltersegmentsqueryaddfieldsitem"></a>
### GetFilterSegmentsQueryAddFieldsItem

<div class="padding-left--md">



#### Enum keys

<div class="padding-left--md">

`Externalid` | `Resourcecontext` | `Variables`

</div>


</div>

<a name="getleanfiltersegmentsqueryaddfieldsitem"></a>
### GetLeanFilterSegmentsQueryAddFieldsItem

<div class="padding-left--md">



#### Enum keys

<div class="padding-left--md">

`Externalid` | `Owner` | `Resourcecontext` | `Variables`

</div>


</div>

<a name="leanfiltersegmentallowedoperationsitem"></a>
### LeanFilterSegmentAllowedOperationsItem

<div class="padding-left--md">

Defines the allowed operations of the current user.

#### Enum keys

<div class="padding-left--md">

`Delete` | `Read` | `Share` | `Write`

</div>


</div>
