import { FilterSegmentVariables } from './filter-segment-variables';
import { Include } from './include';
export interface DetailedFilterSegment {
    /**
     * Unique identifier of the filter-segment.
     */
    uid: string;
    /**
     * Name of the filter-segment.
     */
    name: string;
    /**
     * Description of the filter-segment.
     */
    description?: string;
    /**
     * Variables of the filter-segment.
     */
    variables?: FilterSegmentVariables;
    /**
     * Indicates if the filter-segment is publicly accessible within the tenant.
     */
    isPublic?: boolean;
    /**
     * Defines the owner of the filter-segment.
     */
    owner: string;
    /**
     * Defines the allowed operations of the current user.
     */
    allowedOperations?: Array<'READ' | 'WRITE' | 'DELETE' | 'SHARE'>;
    /**
     * List of includes of the filter-segment.
     */
    includes?: Include[];
    /**
     * Optional unique identifier of the filter-segment. Used for Dynatrace Configuration as Code
     */
    externalId?: string;
    /**
     * Used for optimistic locking. Update requests define with this on which version the data updated is based on. This must match with the version stored, otherwise the update will fail due to concurrent modification.
     */
    version?: number;
}
